@@ -21,24 +21,24 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-//#include "logging.h"
+#include "logging.h"
 
 dwg_inthash *
 hash_new (uint32_t size)
 {
-  dwg_inthash *hash = malloc (sizeof (dwg_inthash));
+  dwg_inthash *hash = (dwg_inthash *)malloc (sizeof (dwg_inthash));
   uint32_t cap;
   if (!hash)
     return NULL;
   // multiply with load factor,
   // and round size to next power of 2 (fast) or prime (secure),
-  if (!size)
+  if (size < 15)
     size = 15;
   cap = (uint32_t) (size * 100.0 / HASH_LOAD);
-  while (size
-         <= cap) // this is slow, but only done once. clz would be much faster
+  // this is slow, but only done once. clz would be much faster
+  while (size <= cap)
     size <<= 1U;
-  hash->array = calloc (size, sizeof (struct _hashbucket)); // key+value pairs
+  hash->array = (struct _hashbucket *)calloc (size, sizeof (struct _hashbucket)); // key+value pairs
   hash->elems = 0;
   hash->size = size;
   return hash;
@@ -59,7 +59,7 @@ hash_resize (dwg_inthash *hash)
   uint32_t i;
 
   // allocate key+value pairs afresh
-  hash->array = calloc (size, sizeof (struct _hashbucket));
+  hash->array = (struct _hashbucket *)calloc (size, sizeof (struct _hashbucket));
   if (!hash->array)
     {
       *hash = oldhash;
@@ -100,7 +100,7 @@ hash_get (dwg_inthash *hash, uint32_t key)
   uint32_t j = i;
   while (hash->array[i].key && hash->array[i].key != key)
     {
-      // fprintf(stderr, "get collision at %d\n", i);
+      //HANDLER (OUTPUT, "get collision at %d\n", i);
       i++; // linear probing with wrap around
       if (i == hash->size)
         i = 0;
@@ -121,7 +121,7 @@ hash_set (dwg_inthash *hash, uint32_t key, uint32_t value)
   uint32_t j = i;
   if (key == 0)
     {
-      fprintf (stderr, "forbidden 0 key\n");
+      HANDLER (OUTPUT, "forbidden 0 key\n");
       return;
     }
   // empty slot
@@ -139,30 +139,30 @@ hash_set (dwg_inthash *hash, uint32_t key, uint32_t value)
           hash->array[i].value = value;
           return;
         }
-      // fprintf(stderr, "set collision at %d\n", i);
+      // HANDLER (OUTPUT, "set collision at %d\n", i);
       i++; // linear probing with wrap around
       if (i == hash->size)
         i = 0;
       if (i == j) // not found
         {
-          // fprintf(stderr, "set not found at %d\n", i);
+          // HANDLER (OUTPUT, "set not found at %d\n", i);
           // if does not exist, add at i+1
           if (hash_need_resize (hash))
             {
-              // fprintf(stderr, "resize at %d\n", hash->size);
+              // HANDLER (OUTPUT, "resize at %d\n", hash->size);
               hash_resize (hash);
               return hash_set (hash, key, value);
             }
           while (hash->array[i].key) // find next empty slot
             {
               // up to here we have no coverage!
-              // fprintf(stderr, "set 2nd collision at %d\n", i);
+              // HANDLER (OUTPUT, "set 2nd collision at %d\n", i);
               i++; // again linear probing with wrap around
               if (i == hash->size)
                 i = 0;
               if (i == j) // not found
                 {
-                  // fprintf(stderr, "not found resize at %d\n", hash->size);
+                  // HANDLER (OUTPUT, "not found resize at %d\n", hash->size);
                   hash_resize (hash); // guarantees new empty slots
                   hash_set (hash, key, value);
                   return;
